======================
scrapy-zyte-smartproxy
======================

.. image:: https://img.shields.io/pypi/v/scrapy-zyte-smartproxy.svg
   :target: https://pypi.python.org/pypi/scrapy-zyte-smartproxy
   :alt: PyPI Version

.. image:: https://travis-ci.org/scrapy-plugins/scrapy-zyte-smartproxy.svg?branch=master
   :target: http://travis-ci.org/scrapy-plugins/scrapy-zyte-smartproxy
   :alt: Build Status

.. image:: http://codecov.io/github/scrapy-plugins/scrapy-zyte-smartproxy/coverage.svg?branch=master
   :target: http://codecov.io/github/scrapy-plugins/scrapy-zyte-smartproxy?branch=master
   :alt: Code Coverage

scrapy-zyte-smartproxy provides easy use of `Zyte Smart Proxy Manager
<https://www.zyte.com/smart-proxy-manager/>`_ (formerly Crawlera) with Scrapy.

Requirements
============

* Python 2.7 or Python 3.4+
* Scrapy

Installation
============

You can install scrapy-zyte-smartproxy using pip::

    pip install scrapy-zyte-smartproxy


Documentation
=============

Documentation is available online at
https://scrapy-zyte-smartproxy.readthedocs.io/ and in the ``docs`` directory.
